@@ -167,7 +167,8 @@ class PEAR
      * @access public
      * @return void
      */
-    function PEAR($error_class = null)
+//    function PEAR($error_class = null)
+	function __construct($error_class = null)
     {
         $classname = strtolower(get_class($this));
         if ($this->_debug) {
@@ -849,7 +850,8 @@ class PEAR_Error
      * @access public
      *
      */
-    function PEAR_Error($message = 'unknown error', $code = null,
+//    function PEAR_Error($message = 'unknown error', $code = null,
+    function __construct($message = 'unknown error', $code = null,
                         $mode = null, $options = null, $userinfo = null)
     {
         if ($mode === null) {
