@@ -285,7 +285,7 @@ class admin_mainSmenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		}
 		
 		// メニューID選択メニュー作成
-		$this->db->getMenuIdList(array($this, 'menuIdListLoop'));
+		$this->db->getMenuIdList(-1/*すべてのアクセスポイントが対象*/, array($this, 'menuIdListLoop'), false/*ウィジェット専用のメニューは取得しない*/, true/*有効なアクセスポイントのみ取得*/);
 		
 		// メニュー項目一覧を作成
 		$this->createMenuList($this->menuId);
