@@ -1,6 +1,6 @@
 <?php
 /**
- * コンテナクラス
+ * index.php用コンテナクラス
  *
  * PHP versions 5
  *
@@ -8,40 +8,26 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ec_mainDelivmethodWidgetContainer.php 2264 2009-08-28 06:08:21Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
-require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainOrderDb.php');
-require_once($gEnvManager->getCurrentWidgetDbPath()	. '/ec_mainCartDb.php');
-require_once($gEnvManager->getCurrentWidgetDbPath() .	'/productDb.php');
-require_once($gEnvManager->getCurrentWidgetLibPath() .	'/cart.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/ec_mainBaseWidgetContainer.php');
 
-class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
+class ec_mainDelivmethodWidgetContainer extends ec_mainBaseWidgetContainer
 {
-	private $db;	// DB接続オブジェクト
-	private $cartDb;		// カートアクセス用ＤＢオブジェクト
-	private $productDb;	// DB接続オブジェクト
-	private $ecObj;		// 価格計算
-	private $cartObj;		// カート処理
 	private $zipcode;	// 郵便番号
 	private $stateId;	// 都道府県ID
 	private $deliveryMethod;		// 配送方法
+	private $deliveryMethodCount;	// 配送方法総数
 	private $cartId;
-	private $userId;		// 現在のユーザ
-	private $langId;		// 現在の言語
 	private $productTotal;		// 商品合計額
 	private $productCount;		// 商品総数
 	private $demandTime;	// 希望時間帯
 	private $demandDt;		// 希望日
 	private $replaceNew;		// データを再取得するかどうか
-	const PRICE_OBJ_ID = "eclib";		// 価格計算オブジェクトID
 	const DEFAULT_COUNTRY_ID = 'JPN';	// デフォルト国ID
-	const STANDARD_PRICE = 'selling';		// 通常価格
-	const NEXT_TASK = 'payment';		// 購入処理中の次の処理
-	const GOBACK_TASK = 'delivery';		// 購入処理中の前の処理
 	
 	/**
 	 * コンストラクタ
@@ -50,15 +36,6 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 	{
 		// 親クラスを呼び出す
 		parent::__construct();
-		
-		// DB接続オブジェクト作成
-		$this->db = new ec_mainOrderDb();
-		$this->cartDb = new ec_mainCartDb();
-		$this->productDb = new productDb();
-		
-		// オブジェクト作成
-		$this->ecObj = $this->gInstance->getObject(self::PRICE_OBJ_ID);		// 価格計算用
-		$this->cartObj = new cart();		// カート処理
 	}
 	/**
 	 * テンプレートファイルを設定
@@ -85,18 +62,14 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
-		$now = date("Y/m/d H:i:s");	// 現在日時
-		$countryId = self::DEFAULT_COUNTRY_ID;			// デフォルト国ID
-		$this->langId	= $this->gEnv->getCurrentLanguage();		// 表示言語を取得
-		$this->userId = $this->gEnv->getCurrentUserId();
-		$defaultCurrency = $this->ecObj->getDefaultCurrency();		// 通貨
-		
+		$defaultCurrency = ec_mainCommonDef::DEFAULT_CURRENCY;		// 通貨
+
 		// 初期データ取得
 		// クッキー読み込み、カートIDを取得。カートの商品を集計する(配送料金の計算に必要)
 		$this->cartId = $request->getCookieValue(M3_COOKIE_CART_ID);
 		$this->productTotal = 0;		// 合計価格
 		$this->productCount = 0;		// 商品総数
-		$ret = $this->cartObj->getTotalPrice($this->cartId, $this->langId, $price, $count);
+		$ret = $this->getTotalPrice($price, $count);
 		if ($ret){
 			$this->productTotal = $price;
 			$this->productCount = $count;	// 商品総数
@@ -113,16 +86,8 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 			
 			// エラーなしの場合
 			if ($this->getMsgCount() == 0){
-				// 保存値を取得
-				if (empty($this->userId)){			// 非会員の購入の場合
-					$cid = $this->gAccess->getClientId();			// ブラウザのクライアントID
-					$ret = $this->db->getOrderSheetByClientId($cid, $row);		// クライアントIDで注文情報を取得
-					if (!$ret) $this->db->delOrderSheetByClientId($this->gAccess->getClientId());		// エラーのときはエラーデータを削除
-				} else {
-					// 受注処理
-					$cid = '';			// ブラウザのクライアントIDは使用しない
-					$ret = $this->db->getOrderSheet($this->userId, $this->langId, $row);
-				}
+				// 注文書を取得
+				$ret = $this->_getOrderSheet($row);
 				if ($ret){
 					// 配送料計算に必要な変数を取得
 					$this->zipcode = $row['oe_deliv_zipcode'];	// 郵便番号
@@ -135,14 +100,15 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 					$this->demandTime = '';	// 希望時間帯
 					$this->demandDt = $this->gEnv->getInitValueOfTimestamp();		// 希望日
 					$appoint_dt = $this->gEnv->getInitValueOfTimestamp();		// 予定納期
-					if ($this->db->getDelivMethod($this->deliveryMethod, $this->langId, 0/*デフォルトのセットID*/, $delivMethodRow)){
+					if (self::$_orderDb->getDelivMethod($this->deliveryMethod, $this->_langId, 0/*デフォルトのセットID*/, $delivMethodRow)){
 						$iWidgetId	= $delivMethodRow['do_iwidget_id'];	// インナーウィジェットID
 						if (!empty($iWidgetId)){
 							// パラメータをインナーウィジェットに設定し、計算結果を取得
+							$optionParam = new stdClass;
 							$optionParam->id = $delivMethodRow['do_id'];
 							$optionParam->init = true;		// 初期データ取得
-							$optionParam->userId = $this->userId;					// ログインユーザID
-							$optionParam->languageId = $this->langId;		// 言語ID
+							$optionParam->userId = $this->_userId;					// ログインユーザID
+							$optionParam->languageId = $this->_langId;		// 言語ID
 							$optionParam->cartId = $this->cartId;					// 商品のカート
 							$optionParam->productTotal = $subtotal;				// 商品総額
 							$optionParam->productCount = $this->productCount;	// 商品総数
@@ -159,7 +125,7 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 					$discount = 0;		// 値引き額
 					$total = $subtotal - $discount + $deliv_fee + $charge;		// 総支払額を求める
 						
-					$ret = $this->db->updateOrderSheet($this->userId, $this->langId, $cid,
+					$ret = self::$_orderDb->updateOrderSheet($this->_userId, $this->_langId, $this->_getClientId(),
 						$row['oe_custm_id'], $row['oe_custm_name'], $row['oe_custm_name_kana'], $row['oe_custm_person'], $row['oe_custm_person_kana'],
 						$row['oe_custm_zipcode'], $row['oe_custm_state_id'], $row['oe_custm_address1'], $row['oe_custm_address2'], $row['oe_custm_phone'], $row['oe_custm_fax'], $row['oe_custm_email'], $row['oe_custm_country_id'], 
 						$row['oe_deliv_id'], $row['oe_deliv_name'], $row['oe_deliv_name_kana'], $row['oe_deliv_person'], $row['oe_deliv_person_kana'],
@@ -172,7 +138,7 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 						$this->replaceNew = true;		// データを再取得
 						
 						// エラーがなければ次の画面へ
-						$nextPage = $this->gEnv->createCurrentPageUrl() . '&task=' . self::NEXT_TASK;
+						$nextPage = $this->gEnv->createCurrentPageUrl() . '&task=' . $this->_getOrderNextTask();
 						$this->gPage->redirect($nextPage);
 						return;
 					}
@@ -182,13 +148,8 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 		} else {		// 初期表示
 			$this->replaceNew = true;		// データを再取得
 			
-			// すでにデータが登録されている場合は登録データを表示
-			if (empty($this->userId)){			// 非会員の購入の場合
-				$ret = $this->db->getOrderSheetByClientId($this->gAccess->getClientId(), $row);// クライアントIDから登録データを取得
-				if (!$ret) $this->db->delOrderSheetByClientId($this->gAccess->getClientId());		// エラーのときはエラーデータを削除
-			} else {		// 会員の購入の場合
-				$ret = $this->db->getOrderSheet($this->userId, $this->langId, $row);
-			}
+			// 注文書を取得
+			$ret = $this->_getOrderSheet($row);	// 注文情報を取得
 			if ($ret){			// データが既に登録済みのとき
 				$this->zipcode = $row['oe_deliv_zipcode'];
 				$this->stateId = $row['oe_deliv_state_id'];
@@ -198,13 +159,14 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 			}
 		}
 		// 配送方法メニューを作成
-		$this->db->getAllDelivMethod($this->langId, 0/*デフォルトのセットID*/, array($this, 'delivMethodLoop'));
+		$this->deliveryMethodCount = self::$_orderDb->getAllDelivMethodCount($this->_langId);		// 配送方法総数
+		self::$_orderDb->getAllDelivMethod($this->_langId, 0/*デフォルトのセットID*/, array($this, 'delivMethodLoop'));
 		
-		// タイトルのCSSを設定
-		$this->tmpl->addVar("_widget", "class", $this->gDesign->getDefaultContentHeadClassString());		// コンテンツヘッダ用CSSクラス
+		// 選択メッセージを表示
+		if ($this->deliveryMethodCount > 1) $this->tmpl->setAttribute('select_message', 'visibility', 'visible');
 		
 		// 遷移先を設定
-		$this->tmpl->addVar("_widget", "goback_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=' . self::GOBACK_TASK, true));		// 戻りボタン用画面
+		$this->tmpl->addVar("_widget", "goback_url", $this->getUrl($this->gEnv->createCurrentPageUrl() . '&task=' . $this->_getOrderNextTask(-1) . '&act=goback', true));		// 1つ前の画面
 	}
 	/**
 	 * 取得した配送方法をテンプレートに設定する
@@ -222,6 +184,10 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 		$checked = '';
 		if ($isCurrent) $checked = 'checked';
 
+		// 入力コントロールタイプ
+		$inputType = 'radio';
+		if ($this->deliveryMethodCount <= 1) $inputType = 'hidden';			// 配送方法が選択できないとき
+		
 		// 出力を初期化
 		$price = 0;
 		$content = '';
@@ -230,6 +196,7 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 		$iWidgetId	= $fetchedRow['do_iwidget_id'];	// インナーウィジェットID
 		if (!empty($iWidgetId)){
 			// パラメータをインナーウィジェットに設定し、計算結果を取得
+			$optionParam = new stdClass;
 			$optionParam->id = $fetchedRow['do_id'];		// ユニークなID(配送方法ID)
 			// データの更新方法を設定
 			if ($this->replaceNew){		// データを再取得するかどうか
@@ -237,8 +204,8 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 			} else {
 				$optionParam->init = false;		// 画面からの入力データを使用
 			}
-			$optionParam->userId = $this->userId;					// ログインユーザID
-			$optionParam->languageId = $this->langId;		// 言語ID
+			$optionParam->userId = $this->_userId;					// ログインユーザID
+			$optionParam->languageId = $this->_langId;		// 言語ID
 			$optionParam->cartId = $this->cartId;					// 商品のカート
 			$optionParam->productTotal = $this->productTotal;				// 商品総額
 			$optionParam->productCount = $this->productCount;		// 商品総数
@@ -263,6 +230,7 @@ class ec_mainDelivmethodWidgetContainer extends BaseWidgetContainer
 			$unit = '無料';
 		}
 		$row = array(
+			'type'		=> $inputType,			// 入力コントロールタイプ
 			'value'		=> $this->convertToDispString($fetchedRow['do_id']),			// ID
 			'name'		=> $this->convertToDispString($fetchedRow['do_name']),		// 表示名
 			'desc'		=> $fetchedRow['do_description'],							// 説明(HTMLが含まれる)
